geowatch.tasks package
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   geowatch.tasks.cold
   geowatch.tasks.depth
   geowatch.tasks.depth_pcd
   geowatch.tasks.dino_detector
   geowatch.tasks.fusion
   geowatch.tasks.invariants
   geowatch.tasks.landcover
   geowatch.tasks.mae
   geowatch.tasks.metrics
   geowatch.tasks.poly_from_point
   geowatch.tasks.rutgers_material_change_detection
   geowatch.tasks.rutgers_material_seg
   geowatch.tasks.sam
   geowatch.tasks.tracking
   geowatch.tasks.uky_temporal_prediction

Module contents
---------------

.. automodule:: geowatch.tasks
   :members:
   :undoc-members:
   :show-inheritance:
